@@ -34,7 +34,8 @@ class BagFetchQueryProcessor(BaseQueryProcessor):
         if not os.path.isfile(input_manifest):
             return None, None
 
-        with open(input_manifest, "r") as in_file, open(remote_file_manifest, "a") as remote_file:
+        with open(input_manifest, "r", encoding="utf-8") as in_file, \
+                open(remote_file_manifest, "a", encoding="utf-8") as remote_file:
             for line in in_file:
                 # get the required bdbag remote file manifest vars from each line of the json-stream input file
                 entry = json.loads(line)
@@ -87,7 +88,7 @@ class BagFetchQueryProcessor(BaseQueryProcessor):
                 if sha256:
                     sha256 = decodeBase64toHex(sha256)
         # if content length or both hash values are missing, it is a fatal error
-        if not length:
+        if length is None:
             raise DerivaDownloadError("Could not determine Content-Length for %s" % ext_url)
         if not (md5 or sha256):
             raise DerivaDownloadError("Could not locate an MD5 or SHA256 hash for %s" % ext_url)
